Index: src/spaces.h |
=================================================================== |
--- src/spaces.h (revision 2666) |
+++ src/spaces.h (working copy) |
@@ -997,11 +997,11 @@ |
// True if the space has been set up but not torn down. |
bool HasBeenSetup() { return start_ != NULL; } |
// Double the size of the semispace by committing extra virtual memory. |
// Assumes that the caller has checked that the semispace has not reached |
// its maximum capacity (and thus there is space available in the reserved |
// address range to grow). |
- bool Double(); |
+ bool Grow(); |
// Returns the start address of the space. |
Address low() { return start_; } |
@@ -1040,6 +1040,9 @@ |
virtual void Verify(); |
#endif |
+ // Returns the current capacity of the semi space. |
+ int Capacity() { return capacity_; } |
+ |
private: |
// The current and maximum capacity of the space. |
int capacity_; |
@@ -1131,9 +1134,9 @@ |
// Flip the pair of spaces. |
void Flip(); |
// Doubles the capacity of the semispaces. Assumes that they are not at |
// their maximum capacity. Returns a flag indicating success or failure. |
- bool Double(); |
+ bool Grow(); |
// True if the address or object lies in the address range of either |
// semispace (not necessarily below the allocation pointer). |
@@ -997,11 +997,11 @@ |
// True if the space has been set up but not torn down. |
bool HasBeenSetup() { return start_ != NULL; } |
- // Double the size of the semispace by committing extra virtual memory. |
+ // Grow the size of the semispace by committing extra virtual memory. |
// Assumes that the caller has checked that the semispace has not reached |
// its maximum capacity (and thus there is space available in the reserved |
@@ -1131,9 +1134,9 @@ |
// Flip the pair of spaces. |
void Flip(); |
- // Doubles the capacity of the semispaces. Assumes that they are not at |
+ // Grow the capacity of the semispaces. Assumes that they are not at |
// their maximum capacity. Returns a flag indicating success or failure. |